import sqlite3

from PySide6.QtGui import QStandardItemModel


def main_function(ui, db_path, utf_en):
    # 确保 utf_en 是字节字符串
    if not isinstance(utf_en, bytes):
        utf_en = utf_en.encode('utf-8')

    # 设置 QTabWidget 的可见性和标签文本
    tabs_to_show = [(0, '水准测段高差计算成果表')]
    for index in range(ui.tabWidget.count()):
        visible = index in [t[0] for t in tabs_to_show]
        ui.tabWidget.setTabVisible(index, visible)
    for index, text in tabs_to_show:
        ui.tabWidget.setTabText(index, text)

    # 连接到数据库并执行查询
    db1 = sqlite3.connect(db_path)
    db1.text_factory = lambda x: str(x, 'utf-8')
    cursor1 = db1.cursor()

    # 查询 GC_Output_Point 表中的 TableName 字段
    query_table_names = "SELECT DISTINCT TableName FROM GC_Output_Point"
    cursor1.execute(query_table_names)
    table_names = cursor1.fetchall()
    table_names = [name[0] for name in table_names]

    # 打印 TableName 字段的值
    print("Table Names in GC_Output_Point:")
    for name in table_names:
        print(name)

    query = """
    SELECT New_ID, New_ResultName, New_SPName, New_EPName, New_HDiff, New_RLen, Correct_Factor, Period_Diff, Dis_Ass
    FROM GC_Output_Point
    WHERE TableName = ?
    """
    cursor1.execute(query, (utf_en,))
    result = cursor1.fetchall()
    cursor1.close()
    db1.close()

    # 检查查询结果
    if not result:
        print("查询结果为空")
        return

    # 打印查询结果以检查数据类型
    print("查询结果:")
    for row in result:
        print(row)
        # 检查每一列的数据类型
        # for i, value in enumerate(row):
        #     print(f"列 {i} 数据类型: {type(value)}")

#     创建QStandardItemModel 实例
    model = QStandardItemModel()
    model.setColumnCount(len(result[0]))

#     设置表头
    headers = ['序号', '结果期数', '起点', '终点', '高差', '路线长', '修正数', '期间差异', '变形判定']
    model.setHorizontalHeaderLabels(headers)

    for row_data in result:
        items = [QStandardItemModel(str(item))for item in row_data]
        model.appendRow(items)

    ui.resultTableView.setModel(model)
    ui.resultTableView.show()

